@@ -81,4 +81,12 @@ class Profile(InstaBaseObject):
 
 
     def get_name(self):
-        return self.name
\ No newline at end of file
+        return self.name
+
+
+    def follow(self):
+        self.client._follow_user(user=self.username)
+
+    
+    def unfollow(self):
+        self.client._unfollow_user(user=self.username)
\ No newline at end of file
